hepstats.hypotests.calculators package
======================================

.. automodule:: hepstats.hypotests.calculators
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Submodules
----------

.. toctree::
   :maxdepth: 4

   hepstats.hypotests.calculators.asymptotic_calculator
   hepstats.hypotests.calculators.basecalculator
   hepstats.hypotests.calculators.frequentist_calculator
